@@ -23,18 +23,13 @@ from your.formats.filwriter import sigproc_object_from_writer
 # from your.utils.math import primes
 from your.utils.misc import YourArgparseFormatter
 
+from jess.calculators import get_flatten_to
+
 try:
     import cupy as cp
 
-    from jess.calculators_cupy import to_dtype
-    from jess.dispersion_cupy import dedisperse, delay_lost
-    from jess.JESS_filters_cupy import fft_mad, mad_spectra_flat, zero_dm, zero_dm_fft
-
     BACKEND_GPU = True
 except ModuleNotFoundError:
-    from jess.calculators import to_dtype
-    from jess.dispersion import dedisperse, delay_lost
-    from jess.JESS_filters import fft_mad, mad_spectra_flat, zero_dm, zero_dm_fft
 
     BACKEND_GPU = False
 
@@ -107,9 +102,16 @@ def clean_cpu(
 
     # need a bandpass if we do zero_dming, put outside the loop
     if modes_to_zero >= 1:
-        bandpass = np.array(
-            [flatten_to] * yr_input.your_header.nchans, dtype=np.float32
+        bandpass = np.full(
+            yr_input.your_header.nchans, fill_value=flatten_to, dtype=np.float32
         )
+        no_time_detrend = False
+    elif modes_to_zero == 0:
+        # preserve zero DM time series
+        no_time_detrend = True
+    else:
+        # This will be median subtraction
+        no_time_detrend = False
 
     total_flag = np.zeros(3)
     n_iter = 0
@@ -134,6 +136,8 @@ def clean_cpu(
             flatten_to=flatten_to,
             time_median_size=time_median_size,
             return_same_dtype=False,
+            mask_chans=True,
+            no_time_detrend=no_time_detrend,
         )
         cleaned, _, fft_percentage = fft_mad(
             cleaned,
@@ -220,9 +224,16 @@ def clean_gpu(
 
     # need a bandpass if we do zero_dming, put outside the loop
     if modes_to_zero >= 1:
-        bandpass = cp.array(
-            [flatten_to] * yr_input.your_header.nchans, dtype=cp.float32
+        bandpass = cp.full(
+            yr_input.your_header.nchans, fill_value=flatten_to, dtype=cp.float32
         )
+        no_time_detrend = False
+    elif modes_to_zero == 0:
+        # preserve zero DM time series
+        no_time_detrend = True
+    else:
+        # This will be median subtraction
+        no_time_detrend = False
 
     total_flag = cp.zeros(3)
     n_iter = 0
@@ -247,6 +258,8 @@ def clean_gpu(
             flatten_to=flatten_to,
             time_median_size=time_median_size,
             return_same_dtype=False,
+            mask_chans=True,
+            no_time_detrend=no_time_detrend,
         )
         cleaned, _, fft_percentage = fft_mad(
             cleaned,
@@ -343,8 +356,8 @@ def clean_dispersion(
 
     # need a bandpass if we do zero_dming, put outside the loop
     if modes_to_zero >= 1:
-        bandpass = cp.array(
-            [flatten_to] * yr_input.your_header.nchans, dtype=cp.float32
+        bandpass = cp.full(
+            yr_input.your_header.nchans, fill_value=flatten_to, dtype=cp.float32
         )
 
     # add data that can't be dispersed
@@ -358,6 +371,7 @@ def clean_dispersion(
         time_median_size=time_median_size,
         return_same_dtype=False,
         no_time_detrend=True,
+        mask_chans=True,
     )
     cleaned, _, fft_percentage = fft_mad(
         cleaned,
@@ -416,6 +430,7 @@ def clean_dispersion(
             time_median_size=time_median_size,
             no_time_detrend=True,
             return_same_dtype=False,
+            mask_chans=True,
         )
         redisip = dedisperse(
             dedisp, -dispersion_measure, yr_input.your_header.tsamp, yr_input.chan_freqs
@@ -469,6 +484,7 @@ def clean_dispersion(
         time_median_size=time_median_size,
         no_time_detrend=True,
         return_same_dtype=False,
+        mask_chans=True,
     )
     cleaned, _, fft_percentage = fft_mad(
         cleaned,
@@ -508,7 +524,7 @@ def master_cleaner(
     dispersion_measure: float,
     sigma: float = 4,
     gulp: int = 16384,
-    flatten_to: int = 64,
+    flatten_to: Union[int, None] = None,
     channels_per_subband: int = 256,
     time_median_size: int = 32,
     modes_to_zero: int = 1,
@@ -533,6 +549,9 @@ def master_cleaner(
     out_file = get_outfile(file, out_file)
     yr_input = Your(file)
 
+    if flatten_to is None:
+        flatten_to = get_flatten_to(yr_input.your_header.nbits)
+
     wrt = Writer(yr_input, outname=out_file)
     sigproc_object = sigproc_object_from_writer(wrt)
     sigproc_object.write_header(out_file)
@@ -640,7 +659,7 @@ if __name__ == "__main__":
     parser.add_argument(
         "-modes_to_zero",
         "--modes_to_zero",
-        help="Number of modes to zero",
+        help="Number of modes to zero, 0 to preserve zerodm, -1 to median subtract",
         type=int,
         default=1,
         required=False,
@@ -648,9 +667,10 @@ if __name__ == "__main__":
     parser.add_argument(
         "-flatten_to",
         "--flatten_to",
-        help="Flatten data to this number",
+        help="Flatten data to this number. If `None`, sets the data 1/4"
+        + " between zero and dtype max",
         type=int,
-        default=64,
+        default=None,
         required=False,
     )
     parser.add_argument(
@@ -661,6 +681,14 @@ if __name__ == "__main__":
         default=16384,
         required=False,
     )
+    parser.add_argument(
+        "-gpu",
+        "--gpu",
+        help="Which GPU to use. Default is gpu 0, -1 for cpu",
+        type=int,
+        default=0,
+        required=False,
+    )
     # parser.add_argument(
     #    "--remove_ends",
     #    help="keep ends of file that cannot be cleaned",
@@ -692,6 +720,20 @@ if __name__ == "__main__":
             handlers=[RichHandler(rich_tracebacks=True)],
         )
 
+    os.environ["CUDA_VISIBLE_DEVICES"] = f"{args.gpu}"
+    from jess.JESS_filters_generic import mad_spectra_flat
+
+    if args.gpu < 0 or not BACKEND_GPU:
+        from jess.calculators import to_dtype
+        from jess.dispersion import dedisperse, delay_lost
+        from jess.JESS_filters import fft_mad, zero_dm, zero_dm_fft
+
+        BACKEND_GPU = False
+    else:
+        from jess.calculators_cupy import to_dtype
+        from jess.dispersion_cupy import dedisperse, delay_lost
+        from jess.JESS_filters_cupy import fft_mad, zero_dm, zero_dm_fft
+
     master_cleaner(
         file=args.file,
         dispersion_measure=args.dispersion_measure,
