@@ -653,7 +653,7 @@ class TestBalanceChansPerSubband:
         """
         num_section, limits = calc.balance_chans_per_subband(2048, 512)
         assert num_section == 4
-        assert np.array_equal(np.array([0, 512, 1024, 1536, 2048]), limits)
+        np.testing.assert_array_equal(limits, np.array((0, 512, 1024, 1536, 2048)))
 
     @staticmethod
     def test_uneven():
@@ -663,7 +663,18 @@ class TestBalanceChansPerSubband:
         """
         num_section, limits = calc.balance_chans_per_subband(2048, 500)
         assert num_section == 4
-        assert np.array_equal(np.array([0, 512, 1024, 1536, 2048]), limits)
+        np.testing.assert_array_equal(limits, np.array((0, 512, 1024, 1536, 2048)))
+
+    @staticmethod
+    def test_subband_larger_chans():
+        """
+        Test when number of number of chans < chan_per_subband
+        put everything in the subband
+        """
+        num_chans = 500
+        num_section, limits = calc.balance_chans_per_subband(num_chans, 2048)
+        assert num_section == 1
+        np.testing.assert_array_equal(limits, np.array((0, num_chans)))
 
 
 class TestDivideRange:
@@ -701,3 +712,24 @@ def test_to_dtype():
     random_8 = np.clip(random_8, 0, 255)
     random_8 = random_8.astype("uint8")
     assert np.array_equal(random_8, calc.to_dtype(random, np.uint8))
+
+
+class TestGetFlattenTo:
+    """
+    Test flatten to.
+    """
+
+    @staticmethod
+    def test_8():
+        """
+        Test eight bit.
+        """
+        assert 64 == calc.get_flatten_to(8)
+
+    @staticmethod
+    def test_raise():
+        """
+        Below 4 bits is not implemented.
+        """
+        with pytest.raises(NotImplementedError):
+            calc.get_flatten_to(2)
